@@ -39,8 +39,8 @@ class arma_ostream
   {
   public:
   
-  template<typename eT> inline static std::streamsize modify_stream(std::ostream& o, const eT*              data, const u32 n_elem);
-  template<typename  T> inline static std::streamsize modify_stream(std::ostream& o, const std::complex<T>* data, const u32 n_elem);
+  template<typename eT> inline static std::streamsize modify_stream(std::ostream& o, const eT*              data, const uword n_elem);
+  template<typename  T> inline static std::streamsize modify_stream(std::ostream& o, const std::complex<T>* data, const uword n_elem);
   
   template<typename eT> inline static void print_elem_zero(std::ostream& o);
   
