@@ -21,18 +21,18 @@ inline
 const mtOp<typename T1::pod_type, T1, op_var>
 var
   (
-  const Base<typename T1::elem_type,T1>& X,
+  const T1& X,
   const uword norm_type = 0,
   const uword dim = 0,
-  const typename enable_if<resolves_to_vector<T1>::value == false>::result* junk1 = 0,
-  const typename enable_if<is_basevec<T1>::value == false>::result* junk2 = 0
+  const typename enable_if< is_arma_type<T1>::value       == true  >::result* junk1 = 0,
+  const typename enable_if< resolves_to_vector<T1>::value == false >::result* junk2 = 0
   )
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
-  return mtOp<typename T1::pod_type, T1, op_var>(X.get_ref(), norm_type, dim);
+  return mtOp<typename T1::pod_type, T1, op_var>(X, norm_type, dim);
   }
 
 
@@ -42,7 +42,7 @@ inline
 const mtOp<typename T1::pod_type, T1, op_var>
 var
   (
-  const Base<typename T1::elem_type,T1>& X,
+  const T1& X,
   const uword norm_type,
   const uword dim,
   const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk = 0
@@ -51,28 +51,7 @@ var
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  return mtOp<typename T1::pod_type, T1, op_var>(X.get_ref(), norm_type, dim);
-  }
-
-
-
-template<typename T1>
-inline
-arma_warn_unused
-typename T1::pod_type
-var
-  (
-  const Base<typename T1::elem_type,T1>& X,
-  const uword norm_type = 0,
-  const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
-  )
-  {
-  arma_extra_debug_sigprint();
-  arma_ignore(junk1);
-  arma_ignore(junk2);
-  
-  return op_var::var_vec( X.get_ref(), norm_type );
+  return mtOp<typename T1::pod_type, T1, op_var>(X, norm_type, dim);
   }
 
 
@@ -86,7 +65,7 @@ var
   const T1& X,
   const uword norm_type = 0,
   const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<is_basevec<T1>::value == true>::result* junk2 = 0
+  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
   )
   {
   arma_extra_debug_sigprint();
@@ -98,4 +77,15 @@ var
 
 
 
+template<typename T>
+arma_inline
+arma_warn_unused
+const typename arma_scalar_only<T>::result
+var(const T&)
+  {
+  return T(0);
+  }
+
+
+
 //! @}
